@@ -1,4 +1,4 @@
-/** 
+/**
  * @file gnome-cmd-string-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
@@ -30,7 +30,6 @@ struct GnomeCmdStringDialog::Private
     GnomeCmdStringDialogCallback ok_cb;
     GFunc cancel_cb;
     gpointer data;
-    GtkWidget *dialog;
     gchar *error_desc;
 };
 
@@ -178,7 +177,7 @@ GtkType gnome_cmd_string_dialog_get_type ()
 
 GtkWidget *gnome_cmd_string_dialog_new_with_cancel (const gchar *title, const gchar **labels, gint rows, GnomeCmdStringDialogCallback ok_cb, GtkSignalFunc cancel_cb, gpointer user_data)
 {
-    GnomeCmdStringDialog *dialog = (GnomeCmdStringDialog *) g_object_new (GNOME_CMD_TYPE_STRING_DIALOG, NULL);
+    auto *dialog = static_cast< GnomeCmdStringDialog* >(g_object_new (GNOME_CMD_TYPE_STRING_DIALOG, NULL));
 
     gnome_cmd_string_dialog_setup_with_cancel (dialog, title, labels, rows, ok_cb, cancel_cb, user_data);
 
@@ -206,15 +205,6 @@ void gnome_cmd_string_dialog_setup_with_cancel (GnomeCmdStringDialog *dialog, co
 }
 
 
-void gnome_cmd_string_dialog_set_hidden (GnomeCmdStringDialog *dialog, gint row, gboolean hidden)
-{
-    g_return_if_fail (GNOME_CMD_IS_STRING_DIALOG (dialog));
-    g_return_if_fail (row >= 0 && row < dialog->rows);
-
-    gtk_entry_set_visibility (GTK_ENTRY (dialog->entries[row]), !hidden);
-}
-
-
 void gnome_cmd_string_dialog_set_title (GnomeCmdStringDialog *dialog, const gchar *title)
 {
     g_return_if_fail (GNOME_CMD_IS_STRING_DIALOG (dialog));
