@@ -1,4 +1,4 @@
-/** 
+/**
  * @file gnome-cmd-con-list.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
@@ -58,7 +58,11 @@ struct GnomeCmdConList
     void remove(GnomeCmdConDevice *con);
 
     GnomeCmdCon *find_alias(const gchar *alias) const;
-    gboolean has_alias(const gchar *alias) const            {  return find_alias(alias)!=NULL;  }
+
+    gboolean has_alias(const gchar *alias) const
+    {
+        return find_alias(alias) != nullptr;
+    }
 
     GnomeCmdCon *get_home();
     GnomeCmdCon *get_smb();
@@ -78,16 +82,15 @@ struct GnomeCmdConListClass
 
 inline GnomeCmdConList *gnome_cmd_con_list_new ()
 {
-    return (GnomeCmdConList *) g_object_new (GNOME_CMD_TYPE_CON_LIST, NULL);
+    return static_cast<GnomeCmdConList *>(g_object_new (GNOME_CMD_TYPE_CON_LIST, nullptr));
 }
 
 inline GnomeCmdConList *gnome_cmd_con_list_get ()
 {
-    return (GnomeCmdConList *) gnome_cmd_data_get_con_list ();
+    return static_cast<GnomeCmdConList *>(gnome_cmd_data_get_con_list ());
 }
 
 void gnome_cmd_con_list_add_quick_ftp (GnomeCmdConList *list, GnomeCmdConRemote *ftp_con);
-void gnome_cmd_con_list_remove_quick_ftp (GnomeCmdConList *list, GnomeCmdConRemote *ftp_con);
 
 GList *gnome_cmd_con_list_get_all (GnomeCmdConList *list);
 GList *gnome_cmd_con_list_get_all_remote (GnomeCmdConList *list);
