@@ -1,4 +1,4 @@
-/** 
+/**
  * @file gnome-cmd-plain-path.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
@@ -32,18 +32,33 @@ class GnomeCmdPlainPath: public GnomeCmdPath
 
   protected:
 
-    virtual GnomeCmdPlainPath *do_clone() const {  return new GnomeCmdPlainPath(*this);  }
+    virtual GnomeCmdPlainPath *do_clone() const override
+    {
+      return new GnomeCmdPlainPath(*this);
+    }
 
   public:
 
     GnomeCmdPlainPath(const GnomeCmdPlainPath &thePath);
-    explicit GnomeCmdPlainPath(const gchar *plain_path) {  this->path = g_strdup (plain_path);  }
-    virtual ~GnomeCmdPlainPath()                  {  g_free (path);                 }
+    explicit GnomeCmdPlainPath(const gchar *plain_path)
+    {
+      this->path = g_strdup (plain_path);
+    }
+    virtual ~GnomeCmdPlainPath()
+    {
+      g_free (path);
+    }
 
-    virtual const gchar *get_path()               {  return path;                   }
-    virtual const gchar *get_display_path()       {  return path;                   }
-    virtual GnomeCmdPath *get_parent();
-    virtual GnomeCmdPath *get_child(const gchar *child);
+    virtual const gchar *get_path() override
+    {
+      return path;
+    }
+    virtual const gchar *get_display_path() override
+    {
+      return path;
+    }
+    virtual GnomeCmdPath *get_parent() override;
+    virtual GnomeCmdPath *get_child(const gchar *child) override;
 };
 
 inline GnomeCmdPlainPath::GnomeCmdPlainPath(const GnomeCmdPlainPath &thePath)
