@@ -37,7 +37,7 @@ extern "C"
 #include "gnome-cmd-mime-config.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-user-actions.h"
-#include "owner.h"
+#include "gnome-cmd-owner.h"
 #include "gnome-cmd-style.h"
 #include "gnome-cmd-con.h"
 #include "utils.h"
