@@ -121,7 +121,6 @@ inline char *int2string (gint i)
 }
 
 const gchar *type2string (GnomeVFSFileType type, gchar *buf, guint max);
-const gchar *name2string (gchar *filename, gchar *buf, guint max);
 const gchar *perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max);
 const gchar *perm2textstring (GnomeVFSFilePermissions p, gchar *buf, guint max);
 const gchar *perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max);
@@ -216,7 +215,6 @@ GtkWidget *create_ui_pixmap (GtkWidget *window,
 gchar *unix_to_unc (const gchar *path);
 GdkColor *gdk_color_new (gushort r, gushort g, gushort b);
 GList *file_list_to_uri_list (GList *files);
-GList *file_list_to_info_list (GList *files);
 
 int is_dir_existing(const gchar *dpath);
 gboolean create_dir_if_needed (const gchar *dpath);
